@@ -522,8 +522,8 @@ val.prob.ci.2 <- function(p, y, logit, group,
         tryCatch(
           do.call(".rcspline.plot", Argz),
           error = function(e) {
-            nk = Argz$nk
-            warning(paste0("The number of knots led to estimation problems, nk will be set to ", nk), immediate. = TRUE)
+            nk = eval(Argz$nk)
+            warning(paste0("The number of knots led to estimation problems, nk will be set to ", nk - 1), immediate. = TRUE)
             if(nk < 3)
               stop("Nk = 3 led to estimation problems.")
             Argz$nk = nk - 1
